@@ -49,7 +49,7 @@ enum Optcode {
         S_OPT_PLUGIN_READFILE, S_OPT_PLUGIN_PARAMETER, S_OPT_LIST_SCRIPTS, S_OPT_CANVAS,
         S_OPT_KEEP_INJECTIONS, S_OPT_FORCE_STDOUT, S_OPT_LATEX_BEAMER, S_OPT_NO_VERSION_INFO,
         S_OPT_REFORMAT_OPT, S_OPT_RANGE_OPT, S_OPT_BASE16, S_OPT_CATEGORIES, S_OPT_PIPED_FNAME,
-        S_OPT_ISOLATE, S_OPT_MAX_FILE_SIZE
+        S_OPT_ISOLATE, S_OPT_MAX_FILE_SIZE, S_OPT_SYNTAX_SUPPORTED
     };
 
 const Arg_parser::Option options[] = {
@@ -120,12 +120,12 @@ const Arg_parser::Option options[] = {
         { S_OPT_EOL_DELIM_CR,     OPT_EOL_DELIM_CR,    Arg_parser::no },
         { S_OPT_PRINT_STYLE,      OPT_PRINT_STYLE,     Arg_parser::no },
         { S_OPT_BASE16,           OPT_BASE16,          Arg_parser::maybe },
-        { S_OPT_NO_TRAILING_NL,   OPT_NO_TRAILING_NL,  Arg_parser::no },
+        { S_OPT_NO_TRAILING_NL,   OPT_NO_TRAILING_NL,  Arg_parser::maybe },
         { S_OPT_KEEP_INJECTIONS,  OPT_KEEP_INJECTIONS, Arg_parser::no },
         { S_OPT_FORCE_STDOUT,     OPT_FORCE_STDOUT,    Arg_parser::no },
         { S_OPT_LATEX_BEAMER,     OPT_LATEX_BEAMER,    Arg_parser::no },
         { S_OPT_NO_VERSION_INFO,  OPT_NO_VERSION_INFO, Arg_parser::no },
-        
+
         { S_OPT_PLUGIN,           OPT_PLUGIN,          Arg_parser::yes },
         { S_OPT_PLUGIN_READFILE,  OPT_PLUGIN_READFILE, Arg_parser::yes },
         { S_OPT_PLUGIN_PARAMETER, OPT_PLUGIN_PARAMETER, Arg_parser::yes },
@@ -138,8 +138,8 @@ const Arg_parser::Option options[] = {
         { S_OPT_PIPED_FNAME,      OPT_PIPED_FNAME,     Arg_parser::yes },
         { S_OPT_ISOLATE,          OPT_ISOLATE_TAGS,    Arg_parser::no },
         { S_OPT_MAX_FILE_SIZE,    OPT_MAX_FILE_SIZE,   Arg_parser::yes },
-        //{ S_OPT_TWO_PASS,         OPT_TWO_PASS,        Arg_parser::yes },
-        
+        { S_OPT_SYNTAX_SUPPORTED, OPT_SYNTAX_SUPPORTED, Arg_parser::no },
+
         { 0, 0, Arg_parser::no }
     };
 
@@ -152,6 +152,7 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
     lineNrStart ( 1 ),
     lineRangeStart( 0 ),
     lineRangeEnd( 0 ),
+    opt_no_trailing_nl(0),
     canvasPaddingWidth(0),
     wrappingStyle ( highlight::WRAP_DISABLED ),
     outputType ( highlight::HTML ),
@@ -189,20 +190,20 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
     opt_delim_CR (false),
     opt_print_style(false),
     opt_base16_theme(false),
-    opt_no_trailing_nl(false),
     opt_keep_injections(false),
     opt_force_stdout(false),
     opt_no_version_info(false),
     explicit_output_format(false),
     opt_isolate(false),
     opt_encoding_explicit(false),
+    opt_syntax_supported_check(false),
     maxFileSize(268435456),
     fallbackSyntax("txt"),
     anchorPrefix ( "l" ),
     helpLang ( "en" ),
     encodingName ( "ISO-8859-1" )
 {
-    
+
     char* hlEnvOptions=getenv("HIGHLIGHT_OPTIONS");
     if (hlEnvOptions!=NULL) {
         std::ostringstream envos;
@@ -213,15 +214,15 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
         std::vector<char*> options;
         while (ss >> arg)
         {
-            ls.push_back(arg); 
+            ls.push_back(arg);
             options.push_back(const_cast<char*>(ls.back().c_str()));
         }
-        options.push_back(0); 
+        options.push_back(0);
         parseRuntimeOptions(options.size()-1, (const char**) &options[0], false);
     }
-    
+
     parseRuntimeOptions(argc, argv);
-    
+
     if ( skipArg.size() && inputFileNames.size() > 1) {
         istringstream valueStream;
         string elem;
@@ -230,7 +231,7 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
         while ( getline ( valueStream, elem, ';' ) ) {
             ignoredFileTypes.insert ( elem );
         }
-       
+
         vector<string>::iterator file=inputFileNames.begin();
         while ( file!=inputFileNames.end()) {
             for ( set<string>::iterator ext=ignoredFileTypes.begin(); ext!=ignoredFileTypes.end(); ext++ ) {
@@ -243,9 +244,9 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
                 file++;
         }
     }
-    
+
     // no batch mode + no explicit format given
-    if (inputFileNames.size()==1 && !explicit_output_format){
+    if (inputFileNames.size()==1 && !explicit_output_format) {
         int colorOptions = Platform::isColorEscCapable();
         if (colorOptions) {
             outputType = colorOptions==2 ? highlight::ESC_TRUECOLOR : highlight::ESC_XTERM256;
@@ -256,7 +257,7 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
 CmdLineOptions::~CmdLineOptions() {}
 
 void CmdLineOptions::parseRuntimeOptions( const int argc, const char *argv[], bool readInputFilenames) {
-    
+
 
     Arg_parser parser ( argc, argv, options );
     if ( parser.error().size() ) { // bad option
@@ -264,7 +265,7 @@ void CmdLineOptions::parseRuntimeOptions( const int argc, const char *argv[], bo
         cerr << "Try 'highlight --help' for more information.\n";
         exit ( EXIT_FAILURE );
     }
-    
+
     int argind = 0;
     for ( ; argind < parser.arguments(); ++argind ) {
         const int code = parser.code ( argind );
@@ -403,18 +404,17 @@ void CmdLineOptions::parseRuntimeOptions( const int argc, const char *argv[], bo
         case 's':
             styleName = arg;
             if (Platform::fileExists(styleName)){
-                absThemePath = styleName; 
+                absThemePath = styleName;
             }
             break;
         case 'S':
         case S_OPT_COMPAT_SRCLANG:
             syntax = arg;
             opt_syntax = true;
-            
-            if (Platform::fileExists(arg)){
+
+            if (Platform::fileExists(arg) && string::npos!=arg.find_last_of('.')){
                 absLangPath = arg;
                 syntax = arg.substr(0, arg.find_last_of('.'));
-           
             }
             break;
         case 't':
@@ -457,7 +457,7 @@ void CmdLineOptions::parseRuntimeOptions( const int argc, const char *argv[], bo
             opt_force_output = true;
             if  ( !arg.empty() ) {
                 fallbackSyntax=arg;
-            } 
+            }
             break;
         case S_OPT_INLINE_CSS:
             opt_inline_css=true;
@@ -470,6 +470,8 @@ void CmdLineOptions::parseRuntimeOptions( const int argc, const char *argv[], bo
                 keywordCase = StringTools::CASE_LOWER;
             else if ( tmp == "capitalize" )
                 keywordCase = StringTools::CASE_CAPITALIZE;
+            else
+                cerr << "highlight: unknown argument " << arg << endl;
         }
         break;
         case S_OPT_PRINT_CONFIG:
@@ -516,7 +518,7 @@ void CmdLineOptions::parseRuntimeOptions( const int argc, const char *argv[], bo
         case S_OPT_COMPAT_LINEREF:
             opt_linenumbers = true;
             opt_attach_line_anchors = true;
-            anchorPrefix = ( arg.empty() ) ? "line":arg;
+            anchorPrefix = ( arg.empty() ) ? "line" : arg;
             break;
         case S_OPT_EOL_DELIM_CR:
             opt_delim_CR = true;
@@ -533,7 +535,14 @@ void CmdLineOptions::parseRuntimeOptions( const int argc, const char *argv[], bo
                 styleName = arg;
             break;
         case S_OPT_NO_TRAILING_NL:
-            opt_no_trailing_nl = true;
+            opt_no_trailing_nl = 1;
+            if (arg.size()) {
+              if (arg=="empty-file")
+                  opt_no_trailing_nl = 2;
+              else
+                  cerr << "highlight: unknown argument " << arg << endl;
+            }
+
             break;
         case S_OPT_KEEP_INJECTIONS:
             opt_keep_injections = true;
@@ -549,7 +558,7 @@ void CmdLineOptions::parseRuntimeOptions( const int argc, const char *argv[], bo
             } else if (arg.find(".theme")!=string::npos) absThemePath=arg;
             else cerr << "highlight: unknown config file type" << endl;
             break;
-        
+
         case S_OPT_RANGE_OPT: {
             size_t delimPos=arg.find("-");
             if (delimPos!=string::npos) {
@@ -568,10 +577,10 @@ void CmdLineOptions::parseRuntimeOptions( const int argc, const char *argv[], bo
         case S_OPT_CANVAS:
             canvasPaddingWidth=80;
             numberSpaces=4; // get around problem with maskWs and tab output
-            if  ( !arg.empty() ) 
+            if  ( !arg.empty() )
                 StringTools::str2num<unsigned int> ( canvasPaddingWidth, arg, std::dec );
             break;
-            
+
         case S_OPT_CATEGORIES:
             listScriptCategory=arg;
             if (listScriptType.empty()) listScriptType = "langs";
@@ -592,10 +601,10 @@ void CmdLineOptions::parseRuntimeOptions( const int argc, const char *argv[], bo
             }
             break;
         }
-    //    case S_OPT_TWO_PASS:
-    //        twoPassFile=arg;
-    //        break;
-            
+        case S_OPT_SYNTAX_SUPPORTED:
+            opt_syntax_supported_check = true;
+            break;
+
         default:
             cerr << "highlight: option parsing failed" << endl;
         }
@@ -716,12 +725,13 @@ string CmdLineOptions::getThemeName() const
 {
     if (!styleName.empty())
         return styleName+".theme";
-    
+
     bool isEscOutput = outputType==highlight::ESC_XTERM256 || outputType==highlight::ESC_TRUECOLOR;
+    bool isDarkTerminal = Platform::isDarkTerminal();
     if (opt_base16_theme)
-        return isEscOutput ? "harmonic-dark.theme" : "harmonic-light.theme";
-    
-    return isEscOutput ? "edit-vim-dark.theme" : "edit-kwrite.theme";
+        return isEscOutput && isDarkTerminal ? "harmonic-dark.theme" : "harmonic-light.theme";
+
+    return isEscOutput && isDarkTerminal ? "edit-vim-dark.theme" : "edit-kwrite.theme";
 }
 
 bool CmdLineOptions::enableBatchMode() const
@@ -735,7 +745,7 @@ bool CmdLineOptions::fragmentOutput() const
 }
 
 bool CmdLineOptions::omitVersionInfo() const {
-    return opt_no_version_info;    
+    return opt_no_version_info;
 }
 
 bool CmdLineOptions::isolateTags() const
@@ -743,6 +753,17 @@ bool CmdLineOptions::isolateTags() const
     return opt_isolate;
 }
 
+bool CmdLineOptions::isSkippedExt ( const string& ext ) const
+{
+    return ignoredFileTypes.count ( ext );
+}
+
+bool CmdLineOptions::checkSyntaxSupport() const
+{
+    return opt_syntax_supported_check;
+}
+
+
 string CmdLineOptions::getOutFileSuffix() const
 {
     switch ( outputType ) {
@@ -903,7 +924,7 @@ bool CmdLineOptions::includePageColor() const
 {
   return opt_page_color;
 }
-bool CmdLineOptions::disableTrailingNL() const
+int CmdLineOptions::disableTrailingNL() const
 {
     return opt_no_trailing_nl;
 }
