@@ -2,7 +2,7 @@
                           main.cpp  -  description
                              -------------------
     begin                : Die Apr 23 22:16:35 CEST 2002
-    copyright            : (C) 2002-2018 by Andre Simon
+    copyright            : (C) 2002-2021 by Andre Simon
     email                : a.simon@mailbox.org
 
    Highlight is a universal source code to HTML converter. Syntax highlighting
@@ -41,25 +41,29 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 
 using namespace std;
 
-void HLCmdLineApp::printVersionInfo()
+void HLCmdLineApp::printVersionInfo(bool quietMode)
 {
-    cout << "\n highlight version "
-         << HIGHLIGHT_VERSION
-         << "\n Copyright (C) 2002-2020 Andre Simon <a dot simon at mailbox.org>"
-         << "\n\n Argparser class"
-         << "\n Copyright (C) 2006-2008 Antonio Diaz Diaz <ant_diaz at teleline.es>"
-         << "\n\n Artistic Style Classes (3.1)"
-         << "\n Copyright (C) 2006-2018 by Jim Pattee <jimp03 at email.com>"
-         << "\n Copyright (C) 1998-2002 by Tal Davidson"
-         << "\n\n Diluculum Lua wrapper (1.0)"
-         << "\n Copyright (C) 2005-2013 by Leandro Motta Barros"
-         << "\n\n xterm 256 color matching functions"
-         << "\n Copyright (C) 2006 Wolfgang Frisch <wf at frexx.de>"
+    if (quietMode) {
+        cout << highlight::Info::getVersion() << "\n";
+    } else {
+        cout << "\n highlight version "
+            << highlight::Info::getVersion()
+            << "\n Copyright (C) 2002-2021 Andre Simon <a dot simon at mailbox.org>"
+            << "\n\n Argparser class"
+            << "\n Copyright (C) 2006-2008 Antonio Diaz Diaz <ant_diaz at teleline.es>"
+            << "\n\n Artistic Style Classes (3.1 rev. 672)"
+            << "\n Copyright (C) 2006-2018 by Jim Pattee <jimp03 at email.com>"
+            << "\n Copyright (C) 1998-2002 by Tal Davidson"
+            << "\n\n Diluculum Lua wrapper (1.0)"
+            << "\n Copyright (C) 2005-2013 by Leandro Motta Barros"
+            << "\n\n xterm 256 color matching functions"
+            << "\n Copyright (C) 2006 Wolfgang Frisch <wf at frexx.de>"
 
-         << "\n\n This software is released under the terms of the GNU General "
-         << "Public License."
-         << "\n For more information about these matters, see the file named "
-         << "COPYING.\n\n";
+            << "\n\n This software is released under the terms of the GNU General "
+            << "Public License."
+            << "\n For more information about these matters, see the file named "
+            << "COPYING.\n\n";
+    }
 }
 
 void HLCmdLineApp::printBadInstallationInfo()
@@ -88,10 +92,10 @@ int HLCmdLineApp::printInstalledFiles(const string& where, const string& wildcar
     string suffix, desc;
     Diluculum::LuaValueMap categoryMap;
     cout << "\nInstalled " << kind << "s";
-    
+
     if (categoryFilterList.size())
         cout << " matching \""<<categoryFilterList<<"\"";
-    
+
     cout << " (located in " << where << "):\n\n";
     int matchedFileCnt=0;
     std::set<string> categoryNames;
@@ -103,14 +107,14 @@ int HLCmdLineApp::printInstalledFiles(const string& where, const string& wildcar
     while ( getline ( valueStream, catFilter, ';' ) ) {
         categoryFilters.insert ( catFilter );
     }
-            
+
     for ( unsigned int i=0; i< filePaths.size(); i++ ) {
         try {
             Diluculum::LuaState ls;
             highlight::SyntaxReader::initLuaState(ls, filePaths[i],"");
             ls.doFile(filePaths[i]);
             desc = ls["Description"].value().asString();
-            
+
             suffix = ( filePaths[i] ).substr ( where.length() ) ;
             suffix = suffix.substr ( 1, suffix.length()- wildcard.length() );
 
@@ -119,23 +123,22 @@ int HLCmdLineApp::printInstalledFiles(const string& where, const string& wildcar
                 filterOKCnt=0;
 
                 categoryMap = ls["Categories"].value().asTable();
-                
-                //TODO: negation
+
                 for(Diluculum::LuaValueMap::const_iterator it = categoryMap.begin(); it != categoryMap.end(); ++it)
                 {
                     categoryNames.insert(it->second.asString());
                     if (categoryFilters.size() && categoryFilters.count(it->second.asString())) {
                         ++filterOKCnt;
                     }
-                }     
+                }
             }
-           
+
             if (filterOKCnt!=categoryFilters.size() && categoryFilters.size() ) continue;
-            
+
             matchedFileCnt++;
             if (kind=="langDef") {
                 cout << setw ( 30 ) <<setiosflags ( ios::left ) <<desc<<": "<<suffix;
-            
+
                 int extCnt=0;
                 for (StringMap::iterator it=dataDir.assocByExtension.begin(); it!=dataDir.assocByExtension.end(); it++) {
                     if (it->second==suffix ) {
@@ -145,35 +148,35 @@ int HLCmdLineApp::printInstalledFiles(const string& where, const string& wildcar
                 cout << ((extCnt)?" )":"");
             } else {
                 cout << setw ( 30 ) <<setiosflags ( ios::left ) <<suffix<<": "<<desc;
-            
+
             }
             cout << endl;
         } catch (std::runtime_error &error) {
             cout << "Failed to read '" << filePaths[i] << "': " << error.what() << endl;
         }
     }
-    
+
     if (!matchedFileCnt) {
         cout <<"No files found." << endl;
     } else {
-        
+
         if (!categoryFilters.size()){
             cout << "\nFound "<<kind<<" categories:\n\n";
             for (std::set<string>::iterator it=categoryNames.begin(); it!=categoryNames.end(); ++it)
                 std::cout << *it<< ' ';
             cout << "\n";
         }
-        
+
         cout <<"\nUse name of the desired "<<kind
             << " with --" << option << ". Filter categories with --list-cat." << endl;
-            
+
         if (kind=="theme") {
             cout <<"\nAdd base16/ prefix to apply a Base16 theme." << endl;
         }
-        
+
         printConfigInfo();
     }
-    
+
     return EXIT_SUCCESS;
 }
 
@@ -181,9 +184,9 @@ void HLCmdLineApp::printDebugInfo ( const highlight::SyntaxReader *lang,
                                     const string & langDefPath )
 {
     if (!lang) return;
-    
+
     map <int, string> HLStateMap;
-    
+
     cerr << "\nLoading language definition:\n" << langDefPath;
     cerr << "\n\nDescription: " << lang->getDescription();
     Diluculum::LuaState* luaState=lang->getLuaState();
@@ -216,23 +219,23 @@ void HLCmdLineApp::printDebugInfo ( const highlight::SyntaxReader *lang,
         }
 
     }
-    
+
     highlight::RegexElement *re=NULL;
     for ( unsigned int i=0; i<lang->getRegexElements().size(); i++ )
     {
         if (i==0)
              cerr << "\nREGEX:\n";
-   
+
         re = lang->getRegexElements() [i];
         cerr << "State "<<re->open<< " ("<< HLStateMap[re->open]<<  "):\t"<<re->pattern <<"\n";
     }
-    
+
     highlight::KeywordMap::iterator it;
     highlight::KeywordMap keys=lang->getKeywords();
     for ( it=keys.begin(); it!=keys.end(); it++ ) {
         if (it==keys.begin())
             cerr << "\nKEYWORDS:\n";
-    
+
         cerr << " "<< it->first << "("<< it->second << ")";
     }
     cerr <<"\n\n";
@@ -294,20 +297,20 @@ void HLCmdLineApp::printIOErrorReport ( unsigned int numberErrorFiles,
                                         vector<string> & fileList,
                                         const string &action, const string &streamName  )
 {
-    
-    
+
+
     cerr << "highlight: Could not "
          << action
          << " file"
          << ( ( numberErrorFiles>1 ) ?"s":"" ) <<":\n";
-    
+
     if (numberErrorFiles==1 && fileList[0].size()==0){
         cerr<<streamName<<"\n";
     }
     else {
         copy ( fileList.begin(), fileList.end(), ostream_iterator<string> ( cerr, "\n" ) );
     }
-    
+
     if ( fileList.size() < numberErrorFiles ) {
         cerr << "... ["
              << ( numberErrorFiles - fileList.size() )
@@ -340,7 +343,7 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
     string dataDirPath = ( options.getDataDir().empty() ) ?  Platform::getAppPath() :options.getDataDir();
 
     if ( options.printVersion() ) {
-        printVersionInfo();
+        printVersionInfo(options.quietMode());
         return EXIT_SUCCESS;
     }
 
@@ -352,7 +355,7 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
     }
 
     if ( options.printConfigInfo() ) {
-        printConfigInfo ( );
+        printConfigInfo();
         return EXIT_SUCCESS;
     }
 
@@ -382,9 +385,30 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
     }
 
     string themePath=options.getAbsThemePath().empty() ? dataDir.getThemePath ( options.getThemeName(), options.useBase16Theme() ): options.getAbsThemePath();
-    
+
     unique_ptr<highlight::CodeGenerator> generator ( highlight::CodeGenerator::getInstance ( options.getOutputType() ) );
 
+    if (options.checkSyntaxSupport()) {
+
+        if (!options.syntaxGiven() ) {
+            cerr << "highlight: Define a syntax to use this option\n";
+            return EXIT_FAILURE;
+        } else {
+            string syntaxByFile=options.getSyntaxByFilename();
+            string testSuffix = syntaxByFile.empty() ? options.getSyntax() : dataDir.getFileSuffix(syntaxByFile);
+            string resolvedSuffix (dataDir.guessFileType (testSuffix, syntaxByFile, syntaxByFile.empty(),false ));
+            string langDefPath (options.getAbsLangPath().empty() ? dataDir.getLangPath ( resolvedSuffix +".lang") : options.getAbsLangPath());
+
+            if (generator->loadLanguage( langDefPath ) == highlight::LOAD_OK) {
+                cout << "highlight: This syntax is supported\n";
+                return EXIT_SUCCESS;
+            } else {
+                cerr << "highlight: This syntax is not supported\n";
+                return EXIT_FAILURE;
+            }
+        }
+    }
+
     generator->setHTMLAttachAnchors ( options.attachLineAnchors() );
     generator->setHTMLOrderedList ( options.orderedList() );
     generator->setHTMLInlineCSS ( options.inlineCSS() );
@@ -396,11 +420,11 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
     generator->setLATEXNoShorthands ( options.disableBabelShorthands() );
     generator->setLATEXPrettySymbols ( options.prettySymbols() );
     generator->setLATEXBeamerMode ( options.enableBeamerMode() );
-    
+
     generator->setRTFPageSize ( options.getPageSize() );
     generator->setRTFCharStyles ( options.includeCharStyles() );
     generator->setRTFPageColor ( options.includePageColor() );
-    
+
     generator->setSVGSize ( options.getSVGWidth(),  options.getSVGHeight() );
 
     generator->setESCCanvasPadding ( options.getCanvasPadding() );
@@ -426,17 +450,16 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
                                   options.getLineLength() - options.getNumberWidth() : options.getLineLength(),
                                   options.getNumberSpaces() );
 
-    //generator->setEncoding ( options.getEncoding() );
     generator->setBaseFont ( options.getBaseFont() ) ;
     generator->setBaseFontSize ( options.getBaseFontSize() ) ;
     generator->setLineNumberWidth ( options.getNumberWidth() );
     generator->setStartingNestedLang( options.getStartNestedLang());
     generator->disableTrailingNL(options.disableTrailingNL());
     generator->setPluginParameter(options.getPluginParameter());
-    
+
     if (options.getLineRangeStart()>0 && options.getLineRangeEnd()>0){
         generator->setStartingInputLine(options.getLineRangeStart());
-        generator->setMaxInputLineCnt(options.getLineRangeEnd());    
+        generator->setMaxInputLineCnt(options.getLineRangeEnd());
     }
 
     bool styleFileWanted = !options.fragmentOutput() || options.styleOutPathDefined();
@@ -483,7 +506,7 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
              << ".\n";
         return EXIT_FAILURE;
     }
-    
+
     generator->setIndentationOptions(options.getAStyleOptions());
 
     string outDirectory = options.getOutDirectory();
@@ -513,24 +536,24 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
     string twoPassOutFile=Platform::getTempFilePath();
     if ( options.syntaxGiven() ) { // user defined language definition, valid for all files
         string syntaxByFile=options.getSyntaxByFilename();
-        string testSuffix = syntaxByFile.empty() ? options.getSyntax() : dataDir.getFileSuffix(syntaxByFile); 
+        string testSuffix = syntaxByFile.empty() ? options.getSyntax() : dataDir.getFileSuffix(syntaxByFile);
         //FIXME
-        suffix = dataDir.guessFileType (testSuffix, syntaxByFile, syntaxByFile.empty(), options.getSingleOutFilename().length()==0 );         
+        suffix = dataDir.guessFileType (testSuffix, syntaxByFile, syntaxByFile.empty(), options.getSingleOutFilename().length()==0 );
     }
 
     generator->setFilesCnt(fileCount);
 
     while ( i < fileCount && !initError ) {
-        
+
         if ( Platform::fileSize(inFileList[i]) > options.getMaxFileSize() ) {
-            
+
             if ( numBadInput++ < IO_ERROR_REPORT_LENGTH || options.printDebugInfo() ) {
                 badInputFiles.push_back ( inFileList[i] + " (size)" );
             }
             ++i;
             continue;
         }
-        
+
         if (i==0 && twoPassMode) {
              if ( !generator->initPluginScript(twoPassOutFile) ) {
                 cerr << "highlight: "
@@ -542,12 +565,13 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
                 break;
             }
         }
-    
+
         if ( !options.syntaxGiven() ) { // determine file type for each file
             suffix = dataDir.guessFileType ( dataDir.getFileSuffix ( inFileList[i] ), inFileList[i] );
         }
-        
+
         if ( suffix.empty()  && options.forceOutput()) suffix=options.getFallbackSyntax(); //avoid segfault
+
         if ( suffix.empty() ) {
             if ( !options.enableBatchMode() )
                 cerr << "highlight: Undefined language definition. Use --"
@@ -559,10 +583,14 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
         }
 
         if ( suffix != lastSuffix ) {
-            
+
             string langDefPath=options.getAbsLangPath().empty() ? dataDir.getLangPath ( suffix+".lang" ) : options.getAbsLangPath();
 
-            highlight::LoadResult loadRes= generator-> loadLanguage( langDefPath );
+            if (!Platform::fileExists(langDefPath) && !options.getFallbackSyntax().empty()) {
+                langDefPath = dataDir.getLangPath ( options.getFallbackSyntax()+".lang" );
+            }
+
+            highlight::LoadResult loadRes= generator->loadLanguage( langDefPath );
 
             if ( loadRes==highlight::LOAD_FAILED_REGEX ) {
                 cerr << "highlight: Regex error ( "
@@ -594,16 +622,16 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
                 printDebugInfo ( generator->getSyntaxReader(), langDefPath );
             }
             lastSuffix = suffix;
-            
+
             string encoding= options.getEncoding();
             //user has explicitly defined the encoding:
             if (!options.encodingDefined()) {
-                
+
                 //syntax definition setting:
                 string encodingHint= generator->getSyntaxEncodingHint();
                 if (encodingHint.size())
                     encoding=encodingHint;
-                
+
                 // filetypes.conf setting has higher priority:
                 encodingHint= dataDir.getEncodingHint(suffix);
                 if (encodingHint.size())
@@ -616,7 +644,7 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
             ++i;
             continue;
         }
-        
+
         string::size_type pos= ( inFileList[i] ).find_last_of ( Platform::pathSeparator );
         inFileName = inFileList[i].substr ( pos+1 );
 
@@ -674,12 +702,12 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
                 badFormattedFiles.push_back ( outFilePath );
             }
         }
-        
+
         ++i;
-        
-        if (i==fileCount && outFilePath.size() && generator->requiresTwoPassParsing() && twoPassOutFile.size() 
+
+        if (i==fileCount && outFilePath.size() && generator->requiresTwoPassParsing() && twoPassOutFile.size()
             && !numBadInput && !numBadOutput && !twoPassMode) {
-            
+
             bool success=generator->printPersistentState(twoPassOutFile);
             if ( !success ) {
                 cerr << "highlight: Could not write "<< twoPassOutFile <<".\n";
@@ -695,7 +723,7 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
                 i=0;
                 lastSuffix.clear();
                 numBadFormatting=0;
-                badFormattedFiles.clear();    
+                badFormattedFiles.clear();
             }
         }
     }
@@ -719,7 +747,7 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
             IOError = true;
         }
     }
-    
+
     if ( numBadInput ) {
         printIOErrorReport ( numBadInput, badInputFiles, "read input", "<stdin>" );
         IOError = true;
@@ -731,17 +759,17 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
     if ( numBadFormatting ) {
         printIOErrorReport ( numBadFormatting, badFormattedFiles, "reformat", "<stdout>" );
     }
-    
+
     vector<string> posTestErrors = generator->getPosTestErrors();
     if (posTestErrors.size()){
         IOError = true;
         printIOErrorReport ( posTestErrors.size(), posTestErrors, "validate", "<stdin>" );
     }
-    
+
     if (twoPassMode) {
         unlink(twoPassOutFile.c_str());
     }
-        
+
     return ( initError || IOError ) ? EXIT_FAILURE : EXIT_SUCCESS;
 }
 
