@@ -2,7 +2,7 @@
                           codegenerator.cpp  -  description
                              -------------------
     begin                : Die Jul 9 2002
-    copyright            : (C) 2002-2020 by Andre Simon
+    copyright            : (C) 2002-2021 by Andre Simon
     email                : a.simon@mailbox.org
  ***************************************************************************/
 
@@ -328,6 +328,11 @@ void CodeGenerator::setBaseFontSize ( const string& fontSize)
     baseFontSize = fontSize;
 }
 
+void CodeGenerator::setStyleCaching ( bool flag )
+{
+    disableStyleCache=!flag;
+}
+
 void CodeGenerator::setStartingNestedLang(const string &langName)
 {
     embedLangStart = langName;
@@ -712,23 +717,12 @@ State CodeGenerator::validateState(State newState, State oldState)
         resultOfHook = res.size()>=1;
         if (resultOfHook) {
 
-            if (currentSyntax->requiresParamUpdate()) {
-
-                 if ( currentSyntax->getOverrideConfigVal("state.string.raw")=="true"){
-                     toggleDynRawString=true; // reset to false in string state fct
-                 }
-                 if ( currentSyntax->getOverrideConfigVal("format.maskws")=="true") {
-                     maskWs=true;
-                 }
-                 if ( currentSyntax->getOverrideConfigVal("format.spacer").size()) {
-                     spacer=currentSyntax->getOverrideConfigVal("format.spacer");
-                 }
-            }
+            setOverrideParams();
 
             State validatedState = (State)res[0].asInteger();
             if ( validatedState== _REJECT) {
+
                 // proceed using only the first character of the token
-                // TODO evaluate if token clear would be better
                 if (res.size()==1) {
                     lineIndex -= (token.length() -1);
                     token=token.substr(0, 1);
@@ -751,7 +745,6 @@ State CodeGenerator::validateState(State newState, State oldState)
     return newState;
 }
 
-
 unsigned int CodeGenerator::getCurrentKeywordClassId(){
     unsigned int kwClassId=0;
 
@@ -786,7 +779,6 @@ void CodeGenerator::maskString ( ostream& ss, const string & s )
     }
 }
 
-
 Diluculum::LuaValueList CodeGenerator::callDecorateFct(const string& token)
 {
 
@@ -795,6 +787,8 @@ Diluculum::LuaValueList CodeGenerator::callDecorateFct(const string& token)
     params.push_back(Diluculum::LuaValue(currentState));
     params.push_back(Diluculum::LuaValue(currentKeywordClass));
     params.push_back(Diluculum::LuaValue(lineContainedStmt));
+    params.push_back(Diluculum::LuaValue(lineNumber) );
+    params.push_back(Diluculum::LuaValue(lineIndex-(unsigned int)token.length()) );
 
     return currentSyntax->getLuaState()->call ( *currentSyntax->getDecorateFct(),
             params,"getDecorateFct call")  ;
@@ -1361,17 +1355,6 @@ LoadResult CodeGenerator::loadLanguage ( const string& langDefPath, bool embedde
                 openTags.push_back ( getKeywordOpenTag ( i ) );
                 closeTags.push_back ( getKeywordCloseTag ( i ) );
             }
-
-            //test balloon
-            string overrideSpacer(currentSyntax->getOverrideConfigVal("spacer"));
-            if (!overrideSpacer.empty()) {
-                spacer = overrideSpacer;
-            }
-            string overrideMaskWS(currentSyntax->getOverrideConfigVal("maskws"));
-            if (!overrideMaskWS.empty()) {
-                maskWs = overrideMaskWS=="true";
-            }
-
         }
     }
     return result;
@@ -1446,7 +1429,7 @@ void CodeGenerator::applyPluginChunk(const string& fctName, string *result, bool
         if (luaState.globals().count(fctName)) {
             Diluculum::LuaFunction* documentFct=new Diluculum::LuaFunction(luaState[fctName].value().asFunction());
 
-            luaState["HL_INPUT_FILE"] = luaState["HL_PLUGIN_PARAM"] = pluginParameter;
+            luaState["HL_PLUGIN_PARAM"] = pluginParameter;
             luaState["HL_OUTPUT"] = outputType;
             luaState["HL_FORMAT_HTML"]=HTML;
             luaState["HL_FORMAT_XHTML"]=XHTML;
@@ -2297,6 +2280,7 @@ bool CodeGenerator::processInterpolationState()
 
 void CodeGenerator::processWsState()
 {
+
     if ( !maskWs ) {
         wsBuffer += token;
         token.clear();
@@ -2313,6 +2297,7 @@ void CodeGenerator::processWsState()
         ++cntWs;
         ++lineIndex;
     }
+
     if ( cntWs>1 ) {
 
         unsigned int styleID=getStyleID ( currentState, currentKeywordClass );
@@ -2322,7 +2307,7 @@ void CodeGenerator::processWsState()
 
         *out << maskWsBegin;
         for ( int i=0; i<cntWs; i++ ) {
-            *out <<  spacer;
+            *out << spacer;
             if (applySyntaxTestCase){
                 stateTraceCurrent.push_back(ps);
             }
@@ -2338,6 +2323,9 @@ void CodeGenerator::processWsState()
             stateTraceCurrent.push_back(ps);
         }
     }
+
+    spacer = initialSpacer;
+
     token.clear();
 }
 
@@ -2352,10 +2340,10 @@ void CodeGenerator::flushWs(int arg)
 
     //fix canvas whitespace
     if (wsBuffer.length() && (outputType==ESC_XTERM256 || outputType==ESC_TRUECOLOR) ){
-        *out<< maskWsBegin;
+        *out<<maskWsBegin;
     }
 
-    *out<<wsBuffer;
+    *out << wsBuffer;
     wsBuffer.clear();
 }
 
@@ -2475,7 +2463,6 @@ void CodeGenerator::runSyntaxTestcases(unsigned int column){
             //TODO Fix ~ws
             if (assertState!=_WS  && !stateTraceTest[column].isWhiteSpace )
                 testFailed=true;
-
         }
 
         if (testFailed) {
@@ -2491,7 +2478,6 @@ void CodeGenerator::runSyntaxTestcases(unsigned int column){
     lineContainedTestCase=true;
 }
 
-
 string CodeGenerator::getNewLine()
 {
     return (printNewLines) ? newLineTag : "";
@@ -2505,8 +2491,21 @@ Diluculum::LuaValueList CodeGenerator::callDecorateLineFct(bool isLineStart)
 
     return currentSyntax->getLuaState()->call ( isLineStart ?
             *currentSyntax->getDecorateLineBeginFct(): *currentSyntax->getDecorateLineEndFct(),
-            params,"getDecorateLineFct call")  ;
+            params,"getDecorateLineFct call");
+}
 
+void CodeGenerator::setOverrideParams() {
+    if (currentSyntax->requiresParamUpdate()) {
+        if ( currentSyntax->getOverrideConfigVal("state.string.raw")=="true"){
+            toggleDynRawString=true; // reset to false in string state fct
+        }
+        if ( currentSyntax->getOverrideConfigVal("format.maskws")=="true") {
+            maskWs=true;
+        }
+        if ( currentSyntax->getOverrideConfigVal("format.spacer").size()) {
+            spacer=currentSyntax->getOverrideConfigVal("format.spacer");
+        }
+    }
 }
 
 void CodeGenerator::insertLineNumber ( bool insertNewLine )
@@ -2515,17 +2514,18 @@ void CodeGenerator::insertLineNumber ( bool insertNewLine )
         if (currentSyntax->getDecorateLineEndFct()) {
             Diluculum::LuaValueList res=callDecorateLineFct(false);
             if (res.size()==1) {
+                setOverrideParams();
                 wsBuffer +=res[0].asString();
             }
         }
-
         wsBuffer += getNewLine();
     }
 
     if (currentSyntax->getDecorateLineBeginFct()) {
         Diluculum::LuaValueList res=callDecorateLineFct(true);
         if (res.size()==1) {
-            wsBuffer +=res[0].asString();
+            setOverrideParams();
+            wsBuffer += res[0].asString();
         }
     }
 
@@ -2545,8 +2545,9 @@ void CodeGenerator::insertLineNumber ( bool insertNewLine )
 
         numberPrefix << openTags[LINENUMBER];
         maskString ( numberPrefix, os.str() );
-        numberPrefix << spacer << closeTags[LINENUMBER];
 
+        //use initialSpacer here, spacer can be overriden by plug-in (format.spacer)
+        numberPrefix << initialSpacer << closeTags[LINENUMBER];
         wsBuffer += numberPrefix.str();
     }
 }
