@@ -3,7 +3,7 @@
                              -------------------
     begin                : Mit Jul 24 2002
     copyright            : (C) 2002 by Andre Simon
-    email                : andre.simon1@gmx.de
+    email                : a.simon@mailbox.org
  ***************************************************************************/
 
 
@@ -40,7 +40,7 @@ LatexGenerator::LatexGenerator()
     // avoid "Underfull \hbox (badness 10000)" warnings
     newLineTag = "\\\\\n";
     longLineTag = "\\hspace*{\\fill}" + newLineTag;
-    spacer = "\\ ";
+    spacer = initialSpacer = "\\ ";
     maskWs=true;
     maskWsBegin = "\\hlstd{";
     maskWsEnd = "}";
@@ -82,10 +82,10 @@ string LatexGenerator::getHeader()
        << "\\usepackage{color}\n"
        << "\\usepackage{alltt}\n"
        << "\\usepackage[T1]{fontenc}\n";
-       
+
     //if (beamerMode)
     //    os  << "\\usepackage{beamerarticle}\n";
-    
+
     if ( StringTools::change_case ( encoding ) == "utf-8" ) {
         os << "\\usepackage{ucs}\n\\usepackage[utf8x]{inputenc}\n";
     } else if ( encodingDefined() ) {
@@ -111,7 +111,7 @@ string LatexGenerator::getHeader()
     os << "\n\\title{" << docTitle << "}\n"
        << "\\begin{document}\n"
        << "\\pagecolor{bgcolor}\n";
-       
+
     if (beamerMode)
       os  << "\\frame{\\frametitle{Code section}\n";
 
@@ -152,17 +152,17 @@ string LatexGenerator::getHeader()
 string LatexGenerator::getFooter()
 {
     ostringstream os;
-    
+
     if (beamerMode)
       os  << "}\n";
 
     os << "\\end {document}\n";
-    
+
     if (!omitVersionComment) {
      os  << "(* LaTeX generated by highlight "
-       << HIGHLIGHT_VERSION
+       << highlight::Info::getVersion()
        << ", "
-       << HIGHLIGHT_URL
+       << highlight::Info::getWebsite()
        << " *)\n";
     }
     return os.str();
@@ -306,9 +306,9 @@ string LatexGenerator::getKeywordCloseTag ( unsigned int styleID )
 
 string LatexGenerator::getStyleDefinition()
 {
-    if ( styleDefinitionCache.empty() ) {
+    if ( disableStyleCache || styleDefinitionCache.empty() ) {
         ostringstream os;
-        
+
         os << "% highlight theme: "<<docStyle.getDescription()<<"\n";
 
         os << getAttributes ( STY_NAME_STD, docStyle.getDefaultStyle() );
