@@ -37,8 +37,7 @@ namespace highlight
 SVGGenerator::SVGGenerator()
     : CodeGenerator ( SVG )
 {
-    //spacer = " ";
-    spacer = "&#160;";
+    spacer = initialSpacer = "&#160;";
     maskWs=true;
     newLineTag = "\n";
     styleCommentOpen="/*";
@@ -113,7 +112,7 @@ string SVGGenerator::getAttributes ( const string & elemName,
 {
     ostringstream s;
     if ( !elemName.empty() ) {
-        s << /*cssClassName<<"."<<*/ elemName<<" { ";
+        s << elemName << " { ";
     }
     s << "fill:#"
       << ( elem.getColour().getRed ( HTML ) )
@@ -177,12 +176,12 @@ string SVGGenerator::getFooter()
 {
     ostringstream os;
     os <<"</svg>\n";
-    
+
     if (!omitVersionComment) {
         os  << "<!-- SVG generated by Highlight "
-            << HIGHLIGHT_VERSION
+            << highlight::Info::getVersion()
             << ", "
-            << HIGHLIGHT_URL
+            << highlight::Info::getWebsite()
             <<" -->\n";
     }
     return os.str();
