@@ -3,7 +3,7 @@
                              -------------------
     begin                : Mit Jul 24 2002
     copyright            : (C) 2002 by Andre Simon
-    email                : andre.simon1@gmx.de
+    email                : a.simon@mailbox.org
  ***************************************************************************/
 
 
@@ -42,7 +42,7 @@ TexGenerator::TexGenerator()
     mode, it switches it to horizontal mode).*/
     newLineTag="\\leavevmode\\par\n";
 
-    spacer = "\\ ";
+    spacer = initialSpacer = "\\ ";
     maskWs=true;
     excludeWs=true;
     maskWsBegin = "{\\hlstd";
@@ -119,12 +119,12 @@ string TexGenerator::getFooter()
 {
     ostringstream os;
     os << "\\bye\n";
-    
+
     if (!omitVersionComment) {
         os  << "% TeX generated by Highlight "
-            << HIGHLIGHT_VERSION
+            << highlight::Info::getVersion()
             << ", "
-            << HIGHLIGHT_URL << "\n";
+            << highlight::Info::getWebsite() << "\n";
     }
     return os.str();
 }
@@ -261,7 +261,7 @@ string TexGenerator::getKeywordCloseTag ( unsigned int styleID )
 
 string TexGenerator::getStyleDefinition()
 {
-    if ( styleDefinitionCache.empty() ) {
+    if ( disableStyleCache || styleDefinitionCache.empty() ) {
         ostringstream os;
         os << "% highlight theme: "<<docStyle.getDescription()<<"\n";
         os << getAttributes ( STY_NAME_STD, docStyle.getDefaultStyle() );
