@@ -2,7 +2,7 @@
                                mainwindow.cpp
                              -------------------
     begin                : Mo 16.03.2009
-    copyright            : (C) 2009-2020 by Andre Simon
+    copyright            : (C) 2009-2021 by Andre Simon
     email                : a.simon@mailbox.org
  ***************************************************************************/
 
@@ -293,8 +293,6 @@ void MainWindow::fillThemeCombo(int restoreVal)
 {
     QString catFilter = ui->comboThemeFilter->currentData().toString();
     bool isBase16 = ui->comboThemeFilter->currentIndex() >1;
-    //catFilter = catFilter.remove(0,2);
-    //qDebug()<<"catFilter "<<catFilter <<isBase16;
 
     ui->comboTheme->clear();
 
@@ -305,7 +303,6 @@ void MainWindow::fillThemeCombo(int restoreVal)
           ui->comboTheme->addItem(curTheme.at(1), curTheme.at(0));
     }
     ui->comboTheme->setCurrentIndex(restoreVal);
-
 }
 
 MainWindow::~MainWindow()
@@ -359,11 +356,7 @@ void MainWindow::addToView(const QStringList& list, QListWidget* listWidget, con
 
 void MainWindow::on_pbOutputDest_clicked()
 {
-    QFileDialog dialog(this, tr("Select destination directory"), "");
-    dialog.setFileMode(QFileDialog::Directory);
-    if (dialog.exec() && !dialog.selectedFiles().empty()) {
-        ui->leOutputDest->setText(dialog.selectedFiles().at(0));
-    }
+    ui->leOutputDest->setText(QFileDialog::getExistingDirectory(this, tr("Select destination directory"), "/home", QFileDialog::ShowDirsOnly | QFileDialog::DontResolveSymlinks));
 }
 
 void MainWindow::writeSettings()
@@ -551,7 +544,7 @@ void MainWindow::readSettings()
     QSettings settings(QSettings::IniFormat, QSettings::UserScope,
                        "andre-simon.de", "highlight-gui");
 
-   // QMessageBox::information(this, "path", settings.fileName());
+    //QMessageBox::information(this, "path", settings.fileName());
     if (!QFile(settings.fileName()).exists()) return;
 
     settings.beginGroup("MainWindow");
@@ -783,7 +776,7 @@ void MainWindow::on_action_About_Highlight_triggered()
     QMessageBox::about( this, "About Highlight",
                         QString("Highlight is a code to formatted text converter.\n\n"
                                 "Highlight GUI %1\n"
-                                "(C) 2002-2020 Andre Simon <a.simon at mailbox.org>\n\n"
+                                "(C) 2002-2021 Andre Simon <a.simon at mailbox.org>\n\n"
                                 "Artistic Style Classes\n(C) 1998-2002 Tal Davidson\n"
                                 "(C) 2006-2018 Jim Pattee <jimp03 at email.com>\n\n"
                                 "Diluculum Lua wrapper\n"
@@ -821,7 +814,6 @@ highlight::OutputType MainWindow::getOutputType()
         return highlight::ESC_XTERM256;
     case 10:
         return highlight::ESC_TRUECOLOR;
-
     }
     return highlight::HTML;
 }
@@ -920,11 +912,10 @@ void MainWindow::applyCtrlValues(highlight::CodeGenerator* generator, bool previ
 
     generator->setPrintLineNumbers( ui->cbIncLineNo->isChecked(), ui->sbLineNoStart->value());
     generator->setPrintZeroes(ui->cbPadZeroes->isEnabled() && ui->cbPadZeroes->isChecked());
-    
-    //TODO Check Windows MB Path
+
     generator->setPluginParameter(ui->lePluginReadFilePath->text().toStdString());
     generator->setOmitVersionComment(ui->cbHTMLPasteMIME->isChecked() || ui->cbOmitVersionInfo->isChecked());
-    
+
     generator->setFilesCnt( previewMode ? 1 :  ui->lvInputFiles->count() );
 
     QString themePath=getUserScriptPath("theme");
@@ -934,12 +925,9 @@ void MainWindow::applyCtrlValues(highlight::CodeGenerator* generator, bool previ
     }
 
 #ifdef Q_OS_WIN
-        themePath = getWindowsShortPath(themePath);                
+        themePath = getWindowsShortPath(themePath);
 #endif
 
-
-    //TODO Check Windows MB Path
-
     for (int i=0; i<ui->lvPluginScripts->count(); i++) {
         if (ui->lvPluginScripts->item(i)->checkState()==Qt::Checked) {
             QString pluginPath=ui->lvPluginScripts->item(i)->data(Qt::UserRole).toString();
@@ -956,7 +944,6 @@ void MainWindow::applyCtrlValues(highlight::CodeGenerator* generator, bool previ
         QMessageBox::critical(this,"Theme init error", QString::fromStdString(generator->getThemeInitError()));
     }
 
-   
     generator->setValidateInput(ui->cbValidateInput->isChecked());
     generator->setLineNumberWidth(ui->sbLineNoWidth->value());
     generator->setNumberWrappedLines(!ui->cbOmitWrappedLineNumbers->isChecked());
@@ -1015,7 +1002,7 @@ void MainWindow::applyEncoding(highlight::CodeGenerator* generator, QString &lan
         string encodingHint= generator->getSyntaxEncodingHint();
         if (encodingHint.size())
             encoding=encodingHint;
-        
+
         // filetypes.conf setting has higher priority:
         encodingHint= encodingHints[QFileInfo(langDefPath).baseName().toStdString()];
         if (encodingHint.size())
@@ -1121,7 +1108,7 @@ void MainWindow::on_pbStartConversion_clicked()
         langDefPath = (userLangPath.isEmpty()) ? getDistLangPath(getFileType(getFileSuffix(currentFile), currentFile)) : userLangPath;
 
 #ifdef Q_OS_WIN
-        langDefPath = getWindowsShortPath(langDefPath);                
+        langDefPath = getWindowsShortPath(langDefPath);
 #endif
 
         loadRes=generator->loadLanguage(langDefPath.toStdString());
@@ -1193,9 +1180,9 @@ void MainWindow::on_pbStartConversion_clicked()
                 generator->setHTMLAnchorPrefix(inFileName.toStdString());
             }
             generator->setTitle(inFileName.toStdString());
-      
+
             applyEncoding(generator.get(), langDefPath);
-            
+
             error = generator->generateFile(currentFile, outfileName );
             if (error != highlight::PARSE_OK) {
                 if (error == highlight::BAD_INPUT) {
@@ -1209,7 +1196,6 @@ void MainWindow::on_pbStartConversion_clicked()
 
         if (i==ui->lvInputFiles->count()-1 && generator->requiresTwoPassParsing() && twoPassOutFile.size()
                     && inputErrors.size()==0 && outputErrors.size()==0 && !twoPassMode) {
-                //QMessageBox::information(this, "print3", "print 3");
 
                 bool success=generator->printPersistentState(twoPassOutFile.toStdString());
                 if ( !success ) {
@@ -1377,101 +1363,97 @@ void MainWindow::highlight2Clipboard(bool getDataFromCP)
     }
 
 #ifdef Q_OS_WIN
-        langPath = getWindowsShortPath(langPath);                
+        langPath = getWindowsShortPath(langPath);
 #endif
 
-      
+
     QString clipBoardData;
 
     for (int twoPass=0; twoPass<2; twoPass++) {
 
-    if ( generator->loadLanguage(langPath.toStdString()) != highlight::LOAD_FAILED) {
-        
-        applyEncoding(generator.get(), langPath);
+        if ( generator->loadLanguage(langPath.toStdString()) != highlight::LOAD_FAILED) {
 
+            applyEncoding(generator.get(), langPath);
 
-        if (getDataFromCP) {
-            clipBoardData= QString::fromStdString( generator->generateString(savedClipboardContent.toStdString()));
-        } else {
-            clipBoardData= QString::fromStdString( generator->generateStringFromFile(previewFilePath.toStdString()));
-        }
-
-        if ( twoPass==0 ) {
-
-           if (generator->requiresTwoPassParsing()) {
-                   // QMessageBox::information(this, "print1", "print 1");
-
-                   if (generator->printPersistentState(twoPassOutFile.toStdString())) {
-                   generator->resetSyntaxReaders();
-                   generator->initPluginScript(twoPassOutFile.toStdString());
-
-                    }
-               continue;
-           } else {
-
-               //TODO method
-               QClipboard *clipboard = QApplication::clipboard();
-               if (clipboard) {
-                   highlight::OutputType outputType = getOutputType();
-                   if ( outputType==highlight::RTF) {
-                       QMimeData *mimeData = new QMimeData();
-       #ifdef Q_OS_WIN
-                       mimeData->setData("Rich Text Format", clipBoardData.toLatin1());
-       #else
-                       mimeData->setData("text/rtf", clipBoardData.toLatin1());
-       #endif
-                       clipboard->setMimeData(mimeData);
-                   }
-                   else if ( (outputType==highlight::HTML || outputType==highlight::XHTML) && ui->cbHTMLPasteMIME->isChecked()) {
-                       QMimeData *mimeData = new QMimeData();
-
-                       if (ui->cbEncoding->isChecked() && ui->comboEncoding->currentText().toLower()=="utf-8") {
-                           mimeData->setHtml(clipBoardData.toUtf8());
-                       } else {
-                           mimeData->setHtml(clipBoardData.toLatin1());
-                       }
-                       clipboard->setMimeData(mimeData);
-                   }
-                   else {
-                       clipboard->setText(clipBoardData);
-                   }
-               }
-
-               break;
-           }
-       }
-
-           //TODO method
-        QClipboard *clipboard = QApplication::clipboard();
-        if (clipboard) {
-            highlight::OutputType outputType = getOutputType();
-            if ( outputType==highlight::RTF) {
-                QMimeData *mimeData = new QMimeData();
-#ifdef Q_OS_WIN
-                mimeData->setData("Rich Text Format", clipBoardData.toLatin1());
-#else
-                mimeData->setData("text/rtf", clipBoardData.toLatin1());
-#endif
-                clipboard->setMimeData(mimeData);
+            if (getDataFromCP) {
+                clipBoardData= QString::fromStdString( generator->generateString(savedClipboardContent.toStdString()));
+            } else {
+                clipBoardData= QString::fromStdString( generator->generateStringFromFile(previewFilePath.toStdString()));
             }
-            else if ( (outputType==highlight::HTML || outputType==highlight::XHTML) && ui->cbHTMLPasteMIME->isChecked()) {
-                QMimeData *mimeData = new QMimeData();
 
-                if (ui->cbEncoding->isChecked() && ui->comboEncoding->currentText().toLower()=="utf-8") {
-                    mimeData->setHtml(clipBoardData.toUtf8());
+            if ( twoPass==0 ) {
+
+                if (generator->requiresTwoPassParsing()) {
+
+                        if (generator->printPersistentState(twoPassOutFile.toStdString())) {
+                            generator->resetSyntaxReaders();
+                            generator->initPluginScript(twoPassOutFile.toStdString());
+                        }
+                        continue;
                 } else {
-                    mimeData->setHtml(clipBoardData.toLatin1());
+
+                    //TODO method
+                    QClipboard *clipboard = QApplication::clipboard();
+                    if (clipboard) {
+                        highlight::OutputType outputType = getOutputType();
+                        if ( outputType==highlight::RTF) {
+                            QMimeData *mimeData = new QMimeData();
+            #ifdef Q_OS_WIN
+                            mimeData->setData("Rich Text Format", clipBoardData.toLatin1());
+            #else
+                            mimeData->setData("text/rtf", clipBoardData.toLatin1());
+            #endif
+                            clipboard->setMimeData(mimeData);
+                        }
+                        else if ( (outputType==highlight::HTML || outputType==highlight::XHTML) && ui->cbHTMLPasteMIME->isChecked()) {
+                            QMimeData *mimeData = new QMimeData();
+
+                                if (ui->cbEncoding->isChecked() && ui->comboEncoding->currentText().toLower()=="utf-8") {
+                                    mimeData->setHtml(clipBoardData.toUtf8());
+                                } else {
+                                    mimeData->setHtml(clipBoardData.toLatin1());
+                                }
+                                clipboard->setMimeData(mimeData);
+                        }
+                        else {
+                            clipboard->setText(clipBoardData);
+                        }
+                    }
+                    break;
                 }
-                clipboard->setMimeData(mimeData);
             }
-            else {
-                clipboard->setText(clipBoardData);
+
+            //TODO method
+            QClipboard *clipboard = QApplication::clipboard();
+            if (clipboard) {
+                highlight::OutputType outputType = getOutputType();
+                if ( outputType==highlight::RTF) {
+                    QMimeData *mimeData = new QMimeData();
+    #ifdef Q_OS_WIN
+                    mimeData->setData("Rich Text Format", clipBoardData.toLatin1());
+    #else
+                    mimeData->setData("text/rtf", clipBoardData.toLatin1());
+    #endif
+                    clipboard->setMimeData(mimeData);
+                }
+                else if ( (outputType==highlight::HTML || outputType==highlight::XHTML) && ui->cbHTMLPasteMIME->isChecked()) {
+                    QMimeData *mimeData = new QMimeData();
+
+                    if (ui->cbEncoding->isChecked() && ui->comboEncoding->currentText().toLower()=="utf-8") {
+                        mimeData->setHtml(clipBoardData.toUtf8());
+                    } else {
+                        mimeData->setHtml(clipBoardData.toLatin1());
+                    }
+                    clipboard->setMimeData(mimeData);
+                }
+                else {
+                    clipboard->setText(clipBoardData);
+                }
             }
+        } else {
+            statusBar()->showMessage(
+                tr("Conversion of \"%1\" not possible.").arg((getDataFromCP)?tr("clipboard data"):previewFilePath));
         }
-    } else {
-        statusBar()->showMessage(
-            tr("Conversion of \"%1\" not possible.").arg((getDataFromCP)?tr("clipboard data"):previewFilePath));
-    }
 
     }
 
@@ -1493,7 +1475,6 @@ void MainWindow::plausibility()
     ui->comboReformat->setEnabled(ui->cbReformat->isChecked());
     ui->comboKwCase->setEnabled(ui->cbKwCase->isChecked());
     ui->comboTheme->setEnabled(getUserScriptPath("theme").isEmpty());
-   // ui->cbUseBase16->setEnabled(getUserScriptPath("theme").isEmpty());
     ui->comboSelectSyntax->setEnabled(getUserScriptPath("lang").isEmpty());
 
     ui->cbHTMLInlineCSS->setEnabled(ui->cbHTMLEmbedStyle->isChecked());
@@ -1571,9 +1552,7 @@ void MainWindow::updatePreview()
     QString croppedName = QFileInfo(previewInputPath).fileName();
 
 #ifdef Q_OS_WIN
-
-        previewInputPath = getWindowsShortPath(previewInputPath);
-
+    previewInputPath = getWindowsShortPath(previewInputPath);
 #endif
 
     if (getDataFromCP) {
@@ -1589,9 +1568,9 @@ void MainWindow::updatePreview()
         langInfo="";
         langPath = getDistLangPath(suffix);
     }
-    
+
 #ifdef Q_OS_WIN
-    langPath = getWindowsShortPath(langPath);                
+    langPath = getWindowsShortPath(langPath);
 #endif
 
     QString themePath = getUserScriptPath("theme");
@@ -1622,7 +1601,6 @@ void MainWindow::updatePreview()
                 statusBar()->showMessage(QString("%1 | %2 | %3").arg(syntaxDesc, themeDesc, contrastDesc));
             }
 
-
             // fix utf-8 data preview - to be improved (other encodings??)
             if (ui->cbEncoding->isChecked() && ui->comboEncoding->currentText().toLower()=="utf-8") {
                 if (getDataFromCP) {
@@ -1640,9 +1618,7 @@ void MainWindow::updatePreview()
 
             if ( twoPass==0 ) {
 
-                if (pwgenerator.requiresTwoPassParsing()
-                   ) {
-                   //QMessageBox::information(this, "print2", "print 2");
+                if (pwgenerator.requiresTwoPassParsing() ) {
 
                    if (pwgenerator.printPersistentState(twoPassOutFile.toStdString())) {
                         pwgenerator.resetSyntaxReaders();
